==> 1.9.8.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItemWidget.dart <==
part of xwidgetbase;

class XItemWidget extends StatelessWidget {
  final Widget? child;
  final String title;
  final Color? titleBackColor;
  final double? heightChildContainer;
  final double? heightHeaders;
  final TextStyle? style;
  final List<Widget>? childrenForHeaders;
  final Widget? childBTNBottom;
  final AlignmentGeometry? alignmentTitleLabel;
  double borderWidth;
  final double? heightTitleContainer;
  final Decoration? decorationTitleContainer;
  final BorderRadiusGeometry? borderRadiusOfItemWidget;
  XItemWidget({
    Key? key,
    this.childrenForHeaders,
    this.alignmentTitleLabel,
    this.heightChildContainer,
    this.style,
    this.childBTNBottom,
    this.heightHeaders,
    this.child,
    this.title = "",
    this.titleBackColor,
    this.borderRadiusOfItemWidget,
    this.decorationTitleContainer,
    this.borderWidth = 1.0,
    this.heightTitleContainer,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // var size = MediaQuery.of(context).size.height;
    return Container(
      // margin: EdgeInsets.all(3),
      decoration: decorationTitleContainer ?? BoxDecoration(border: Border.all(width: borderWidth, color: titleBackColor!), borderRadius: borderRadiusOfItemWidget),
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        title != ""
            ? Container(
                color: titleBackColor,
                child: Row(
                  children: [
                    Expanded(
                      flex: 8,
                      child: Container(
                        margin: EdgeInsets.only(left: 10),
                        height: heightTitleContainer ?? 35,
                        decoration: BoxDecoration(borderRadius: borderRadiusOfItemWidget),
                        color: decorationTitleContainer != null ? null : titleBackColor,
                        alignment: alignmentTitleLabel ?? Alignment.centerLeft,
                        child: Text(
                          title,
                          style: style,
                        ),
                      ),
                    ),
                    childBTNBottom == null
                        ? Container()
                        : Expanded(
                            child: Container(
                              color: titleBackColor,
                              height: 40,
                              child: childBTNBottom,
                            ),
                          ),
                  ],
                ),
              )
            : Container(),
        Row(children: childrenForHeaders ?? [Container()]),
        Container(
          alignment: Alignment.centerLeft,
          height: heightChildContainer ?? null,
          child: child,
        ),
      ]),
    );
  }
}

==> 1.9.9.tar.gz: lib/XWidgets/XItemsComplexWidgets/XItemWidget.dart <==
part of xwidgetbase;

class XItemWidget extends StatelessWidget {
  final Widget? child;
  final String title;
  final Color? titleBackColor;
  final double? heightChildContainer;
  final double? heightHeaders;
  final TextStyle? style;
  final List<Widget>? childrenForHeaders;
  final Widget? childBTNBottom;
  final AlignmentGeometry? alignmentTitleLabel;
  double borderWidth;
  final double? heightTitleContainer;
  final Decoration? decorationTitleContainer;
  final BorderRadiusGeometry? borderRadiusOfItemWidget;
  XItemWidget({
    Key? key,
    this.childrenForHeaders,
    this.alignmentTitleLabel,
    this.heightChildContainer,
    this.style,
    this.childBTNBottom,
    this.heightHeaders,
    this.child,
    this.title = "",
    this.titleBackColor,
    this.borderRadiusOfItemWidget,
    this.decorationTitleContainer,
    this.borderWidth = 1.0,
    this.heightTitleContainer,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    // var size = MediaQuery.of(context).size.height;
    return Container(
      // margin: EdgeInsets.all(3),
      decoration: decorationTitleContainer ?? BoxDecoration(border: Border.all(width: borderWidth, color: titleBackColor!), borderRadius: borderRadiusOfItemWidget),
      child: Column(mainAxisSize: MainAxisSize.min, children: [
        title != ""
            ? Container(
                color: titleBackColor,
                child: Row(
                  children: [
                    Expanded(
                      flex: 8,
                      child: Container(
                        margin: EdgeInsets.only(left: 10),
                        height: heightTitleContainer ?? 35,
                        decoration: BoxDecoration(borderRadius: borderRadiusOfItemWidget, color: titleBackColor),
                        alignment: alignmentTitleLabel ?? Alignment.centerLeft,
                        child: Text(
                          title,
                          style: style,
                        ),
                      ),
                    ),
                    childBTNBottom == null
                        ? Container()
                        : Expanded(
                            child: Container(
                              color: titleBackColor,
                              height: 40,
                              child: childBTNBottom,
                            ),
                          ),
                  ],
                ),
              )
            : Container(),
        Row(children: childrenForHeaders ?? [Container()]),
        Container(
          alignment: Alignment.centerLeft,
          height: heightChildContainer ?? null,
          child: child,
        ),
      ]),
    );
  }
}
